@@ -3,7 +3,7 @@ package format
 import (
 	"fmt"
 
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // OptionalStringerSetting provides a printable version of the given configuration value.
