@@ -3,9 +3,9 @@ package cmdhelpers
 import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/vm/opcodes"
 	"github.com/git-town/git-town/v15/internal/vm/program"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // Wrap makes the given program perform housekeeping before and after it executes.
