@@ -4,22 +4,26 @@ import (
 	"strconv"
 
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // Offline is a new-type for the "offline" configuration setting.
 type Offline bool
 
-func (offline Offline) Bool() bool {
-	return bool(offline)
+func (self Offline) IsFalse() bool {
+	return !self.IsTrue()
 }
 
-func (offline Offline) String() string {
-	return strconv.FormatBool(offline.Bool())
+func (self Offline) IsTrue() bool {
+	return bool(self)
 }
 
-func (offline Offline) ToOnline() Online {
-	return Online(!offline.Bool())
+func (self Offline) String() string {
+	return strconv.FormatBool(self.IsTrue())
+}
+
+func (self Offline) ToOnline() Online {
+	return Online(!self.IsTrue())
 }
 
 func ParseOffline(value, source string) (Option[Offline], error) {
@@ -32,6 +36,6 @@ func ParseOffline(value, source string) (Option[Offline], error) {
 
 type Online bool
 
-func (online Online) Bool() bool {
+func (online Online) IsTrue() bool {
 	return bool(online)
 }
