@@ -6,7 +6,7 @@ import (
 
 	"github.com/git-town/git-town/v15/internal/cli/colors"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // PerennialRegex contains the "branches.perennial-regex" setting.
