@@ -4,7 +4,7 @@ import (
 	"testing"
 
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/shoenig/test/must"
 )
 
@@ -14,7 +14,7 @@ func TestShipDeleteTrackingBranch(t *testing.T) {
 	t.Run("Bool", func(t *testing.T) {
 		t.Parallel()
 		give := configdomain.ShipDeleteTrackingBranch(true)
-		have := give.Bool()
+		have := give.IsTrue()
 		must.True(t, have)
 	})
 
