@@ -1,7 +1,7 @@
 package configdomain
 
 import (
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // SyncFeatureStrategy defines legal values for the "sync-feature-strategy" configuration setting.
@@ -16,8 +16,9 @@ func (self SyncFeatureStrategy) SyncStrategy() SyncStrategy {
 }
 
 const (
-	SyncFeatureStrategyMerge  = SyncFeatureStrategy(SyncStrategyMerge)
-	SyncFeatureStrategyRebase = SyncFeatureStrategy(SyncStrategyRebase)
+	SyncFeatureStrategyMerge    = SyncFeatureStrategy(SyncStrategyMerge)
+	SyncFeatureStrategyRebase   = SyncFeatureStrategy(SyncStrategyRebase)
+	SyncFeatureStrategyCompress = SyncFeatureStrategy(SyncStrategyCompress)
 )
 
 func ParseSyncFeatureStrategy(text string) (Option[SyncFeatureStrategy], error) {
