@@ -2,6 +2,7 @@ package execute
 
 import (
 	"errors"
+	"fmt"
 	"os"
 
 	"github.com/git-town/git-town/v15/internal/config"
@@ -12,16 +13,19 @@ import (
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks"
 	"github.com/git-town/git-town/v15/internal/gohacks/cache"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/messages"
 	"github.com/git-town/git-town/v15/internal/subshell"
 	"github.com/git-town/git-town/v15/internal/undo/undoconfig"
 	"github.com/git-town/git-town/v15/internal/validate"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 func OpenRepo(args OpenRepoArgs) (OpenRepoResult, error) {
 	commandsCounter := NewMutable(new(gohacks.Counter))
+	if args.Verbose {
+		fmt.Println("Git Town " + config.GitTownVersion)
+	}
 	backendRunner := subshell.BackendRunner{
 		Dir:             None[string](),
 		CommandsCounter: commandsCounter,
@@ -79,7 +83,7 @@ func OpenRepo(args OpenRepoArgs) (OpenRepoResult, error) {
 		printCommands:    args.PrintCommands,
 	})
 	isOffline := unvalidatedConfig.Config.Value.Offline
-	if args.ValidateIsOnline && isOffline.Bool() {
+	if args.ValidateIsOnline && isOffline.IsTrue() {
 		err = errors.New(messages.OfflineNotAllowed)
 		return emptyOpenRepoResult(), err
 	}
