@@ -11,9 +11,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks/cache"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/messages"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // Commands are Git commands that Git Town executes to determine which frontend commands to run.
@@ -83,7 +83,7 @@ func (self *Commands) BranchesSnapshot(querier gitdomain.Querier) (gitdomain.Bra
 }
 
 // CheckoutBranch checks out the Git branch with the given name.
-func (self *Commands) CheckoutBranch(runner gitdomain.Runner, name gitdomain.LocalBranchName, merge bool) error {
+func (self *Commands) CheckoutBranch(runner gitdomain.Runner, name gitdomain.LocalBranchName, merge configdomain.SwitchUsingMerge) error {
 	err := self.CheckoutBranchUncached(runner, name, merge)
 	if err != nil {
 		return err
@@ -97,7 +97,7 @@ func (self *Commands) CheckoutBranch(runner gitdomain.Runner, name gitdomain.Loc
 }
 
 // CheckoutBranch checks out the Git branch with the given name.
-func (self *Commands) CheckoutBranchUncached(runner gitdomain.Runner, name gitdomain.LocalBranchName, merge bool) error {
+func (self *Commands) CheckoutBranchUncached(runner gitdomain.Runner, name gitdomain.LocalBranchName, merge configdomain.SwitchUsingMerge) error {
 	args := []string{"checkout", name.String()}
 	if merge {
 		args = append(args, "-m")
@@ -143,9 +143,9 @@ func (self *Commands) CommitNoEdit(runner gitdomain.Runner) error {
 }
 
 // CommitStagedChanges commits the currently staged changes.
-func (self *Commands) CommitStagedChanges(runner gitdomain.Runner, message string) error {
+func (self *Commands) CommitStagedChanges(runner gitdomain.Runner, message gitdomain.CommitMessage) error {
 	if message != "" {
-		return runner.Run("git", "commit", "-m", message)
+		return runner.Run("git", "commit", "-m", message.String())
 	}
 	return runner.Run("git", "commit", "--no-edit")
 }
@@ -243,7 +243,7 @@ func (self *Commands) CreateRemoteBranch(runner gitdomain.Runner, localSHA gitdo
 	return runner.Run("git", args...)
 }
 
-// PushBranch pushes the branch with the given name to origin.
+// pushes the branch with the given name to origin
 func (self *Commands) CreateTrackingBranch(runner gitdomain.Runner, branch gitdomain.LocalBranchName, remote gitdomain.Remote, noPushHook configdomain.NoPushHook) error {
 	args := []string{"push"}
 	if noPushHook {
@@ -331,8 +331,11 @@ func (self *Commands) DiscardOpenChanges(runner gitdomain.Runner) error {
 }
 
 // Fetch retrieves the updates from the origin repo.
-func (self *Commands) Fetch(runner gitdomain.Runner) error {
-	return runner.Run("git", "fetch", "--prune", "--tags")
+func (self *Commands) Fetch(runner gitdomain.Runner, syncTags configdomain.SyncTags) error {
+	if syncTags.IsTrue() {
+		return runner.Run("git", "fetch", "--prune", "--tags")
+	}
+	return runner.Run("git", "fetch", "--prune", "--no-tags")
 }
 
 // FetchUpstream fetches updates from the upstream remote.
@@ -340,6 +343,24 @@ func (self *Commands) FetchUpstream(runner gitdomain.Runner, branch gitdomain.Lo
 	return runner.Run("git", "fetch", gitdomain.RemoteUpstream.String(), branch.String())
 }
 
+// provides the commit message of the first commit in the branch with the given name
+func (self *Commands) FirstCommitMessageInBranch(runner gitdomain.Querier, branch, mainBranch gitdomain.BranchName) (Option[gitdomain.CommitMessage], error) {
+	output, err := runner.QueryTrim("git", "log", fmt.Sprintf("%s..%s", mainBranch, branch), "--format=%h")
+	if err != nil {
+		return None[gitdomain.CommitMessage](), err
+	}
+	hashes := stringslice.Lines(output)
+	if len(hashes) == 0 {
+		return None[gitdomain.CommitMessage](), nil
+	}
+	hash := hashes[len(hashes)-1]
+	message, err := runner.QueryTrim("git", "log", "--format=%B", "-n", "1", hash)
+	if err != nil {
+		return None[gitdomain.CommitMessage](), err
+	}
+	return Some(gitdomain.CommitMessage(message)), nil
+}
+
 func (self *Commands) FirstExistingBranch(runner gitdomain.Runner, branches ...gitdomain.LocalBranchName) Option[gitdomain.LocalBranchName] {
 	for _, branch := range branches {
 		if self.BranchExists(runner, branch) {
@@ -349,9 +370,12 @@ func (self *Commands) FirstExistingBranch(runner gitdomain.Runner, branches ...g
 	return None[gitdomain.LocalBranchName]()
 }
 
-// PushBranch pushes the branch with the given name to origin.
-func (self *Commands) ForcePushBranchSafely(runner gitdomain.Runner, noPushHook configdomain.NoPushHook) error {
-	args := []string{"push", "--force-with-lease", "--force-if-includes"}
+// pushes the branch with the given name to origin.
+func (self *Commands) ForcePushBranchSafely(runner gitdomain.Runner, noPushHook configdomain.NoPushHook, forceIfIncludes bool) error {
+	args := []string{"push", "--force-with-lease"}
+	if forceIfIncludes {
+		args = append(args, "--force-if-includes")
+	}
 	if noPushHook {
 		args = append(args, "--no-verify")
 	}
@@ -476,11 +500,6 @@ func (self *Commands) RemotesUncached(querier gitdomain.Querier) (gitdomain.Remo
 	return gitdomain.NewRemotes(stringslice.Lines(out)...), nil
 }
 
-// ResetCurrentBranchToSHA undoes all commits on the current branch all the way until the given SHA.
-func (self *Commands) RemoveCommitsInCurrentBranch(runner gitdomain.Runner, parent gitdomain.LocalBranchName) error {
-	return runner.Run("git", "reset", "--soft", parent.String())
-}
-
 // RemoveGitAlias removes the given Git alias.
 func (self *Commands) RemoveGitAlias(runner gitdomain.Runner, aliasableCommand configdomain.AliasableCommand) error {
 	return runner.Run("git", "config", "--global", "--unset", aliasableCommand.Key().String())
@@ -519,6 +538,11 @@ func (self *Commands) RepoStatus(querier gitdomain.Querier) (gitdomain.RepoStatu
 	}, nil
 }
 
+// ResetCurrentBranchToSHA undoes all commits on the current branch all the way until the given SHA.
+func (self *Commands) ResetBranch(runner gitdomain.Runner, target gitdomain.BranchName) error {
+	return runner.Run("git", "reset", "--soft", target.String())
+}
+
 // ResetCurrentBranchToSHA undoes all commits on the current branch all the way until the given SHA.
 func (self *Commands) ResetCurrentBranchToSHA(runner gitdomain.Runner, sha gitdomain.SHA, hard bool) error {
 	args := []string{"reset"}
@@ -590,8 +614,8 @@ func (self *Commands) SetOriginHostname(runner gitdomain.Runner, hostname config
 
 // ShouldPushBranch returns whether the local branch with the given name
 // contains commits that have not been pushed to its tracking branch.
-func (self *Commands) ShouldPushBranch(querier gitdomain.Querier, branch gitdomain.LocalBranchName, trackingBranch gitdomain.RemoteBranchName) (bool, error) {
-	out, err := querier.QueryTrim("git", "rev-list", "--left-right", branch.String()+"..."+trackingBranch.String())
+func (self *Commands) ShouldPushBranch(querier gitdomain.Querier, branch gitdomain.LocalBranchName) (bool, error) {
+	out, err := querier.QueryTrim("git", "rev-list", "--left-right", branch.String()+"..."+branch.TrackingBranch().String())
 	if err != nil {
 		return false, fmt.Errorf(messages.DiffProblem, branch, branch, err)
 	}
