@@ -7,8 +7,8 @@ import (
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks"
 	"github.com/git-town/git-town/v15/internal/gohacks/cache"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/subshell"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	testgit "github.com/git-town/git-town/v15/test/git"
 	"github.com/git-town/git-town/v15/test/testruntime"
 	"github.com/shoenig/test/must"
@@ -22,7 +22,7 @@ func TestBackendCommands(t *testing.T) {
 		t.Parallel()
 		runtime := testruntime.Create(t)
 		branch := gitdomain.NewLocalBranchName("branch")
-		runtime.CreateBranch(branch, initial)
+		runtime.CreateBranch(branch, initial.BranchName())
 		runtime.CreateCommit(testgit.Commit{
 			Branch:      branch,
 			FileContent: "file1",
@@ -46,7 +46,7 @@ func TestBackendCommands(t *testing.T) {
 			t.Parallel()
 			runtime := testruntime.Create(t)
 			branch := gitdomain.NewLocalBranchName("branch")
-			runtime.CreateBranch(branch, initial)
+			runtime.CreateBranch(branch, initial.BranchName())
 			have, err := runtime.TestCommands.BranchHasUnmergedChanges(runtime.TestRunner, branch, initial)
 			must.NoError(t, err)
 			must.False(t, have)
@@ -61,7 +61,7 @@ func TestBackendCommands(t *testing.T) {
 				Message:     "commit 1",
 			})
 			branch := gitdomain.NewLocalBranchName("branch")
-			runtime.CreateBranch(branch, initial)
+			runtime.CreateBranch(branch, initial.BranchName())
 			runtime.CreateCommit(testgit.Commit{
 				Branch:      branch,
 				FileContent: "modified content",
@@ -87,7 +87,7 @@ func TestBackendCommands(t *testing.T) {
 		t.Parallel()
 		runtime := testruntime.Create(t)
 		branch := gitdomain.NewLocalBranchName("branch1")
-		runtime.CreateBranch(branch, initial)
+		runtime.CreateBranch(branch, initial.BranchName())
 		runtime.TestCommands.CheckoutBranch(branch)
 		currentBranch, err := runtime.CurrentBranch(runtime.TestRunner)
 		must.NoError(t, err)
@@ -104,7 +104,7 @@ func TestBackendCommands(t *testing.T) {
 			t.Parallel()
 			runtime := testruntime.Create(t)
 			branch := gitdomain.NewLocalBranchName("branch1")
-			runtime.CreateBranch(branch, initial)
+			runtime.CreateBranch(branch, initial.BranchName())
 			runtime.CreateCommit(testgit.Commit{
 				Branch:   branch,
 				FileName: "file1",
@@ -125,7 +125,7 @@ func TestBackendCommands(t *testing.T) {
 			t.Parallel()
 			runtime := testruntime.Create(t)
 			branch := gitdomain.NewLocalBranchName("branch1")
-			runtime.CreateBranch(branch, initial)
+			runtime.CreateBranch(branch, initial.BranchName())
 			commits, err := runtime.Commands.CommitsInBranch(runtime.TestCommands, branch, Some(gitdomain.NewLocalBranchName("initial")))
 			must.NoError(t, err)
 			must.EqOp(t, 0, len(commits))
@@ -161,7 +161,7 @@ func TestBackendCommands(t *testing.T) {
 		runtime := testruntime.Create(t)
 		runtime.CheckoutBranch(initial)
 		branch := gitdomain.NewLocalBranchName("branch1")
-		runtime.CreateBranch(branch, initial)
+		runtime.CreateBranch(branch, initial.BranchName())
 		runtime.CheckoutBranch(branch)
 		branch, err := runtime.Commands.CurrentBranch(runtime.TestCommands)
 		must.NoError(t, err)
@@ -181,6 +181,98 @@ func TestBackendCommands(t *testing.T) {
 		must.Eq(t, want, have)
 	})
 
+	t.Run("FirstCommitMessageInBranch", func(t *testing.T) {
+		t.Parallel()
+		t.Run("branch is empty", func(t *testing.T) {
+			t.Parallel()
+			repo := testruntime.CreateGitTown(t)
+			must.NoError(t, repo.CreateAndCheckoutBranch(repo.TestRunner, "branch"))
+			have, err := repo.FirstCommitMessageInBranch(repo.TestRunner, "branch", "main")
+			must.NoError(t, err)
+			must.Eq(t, None[gitdomain.CommitMessage](), have)
+		})
+		t.Run("branch has one commit", func(t *testing.T) {
+			t.Parallel()
+			repo := testruntime.CreateGitTown(t)
+			branch := gitdomain.NewLocalBranchName("branch")
+			main := gitdomain.NewLocalBranchName("main")
+			repo.CreateFeatureBranch(branch, main.BranchName())
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file",
+				Message:  "my commit message",
+			})
+			have, err := repo.FirstCommitMessageInBranch(repo.TestRunner, branch.BranchName(), main.BranchName())
+			must.NoError(t, err)
+			want := Some(gitdomain.CommitMessage("my commit message"))
+			must.Eq(t, want, have)
+		})
+		t.Run("branch has multiple commits", func(t *testing.T) {
+			t.Parallel()
+			repo := testruntime.CreateGitTown(t)
+			branch := gitdomain.NewLocalBranchName("branch")
+			main := gitdomain.NewLocalBranchName("main")
+			repo.CreateFeatureBranch(branch, main.BranchName())
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file_1",
+				Message:  "commit message 1",
+			})
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file_2",
+				Message:  "commit message 2",
+			})
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file_3",
+				Message:  "commit message 3",
+			})
+			have, err := repo.FirstCommitMessageInBranch(repo.TestRunner, branch.BranchName(), main.BranchName())
+			must.NoError(t, err)
+			want := Some(gitdomain.CommitMessage("commit message 1"))
+			must.Eq(t, want, have)
+		})
+		t.Run("branch doesn't exist", func(t *testing.T) {
+			t.Parallel()
+			repo := testruntime.CreateGitTown(t)
+			_, err := repo.FirstCommitMessageInBranch(repo.TestRunner, "zonk", "main")
+			must.Error(t, err)
+		})
+		t.Run("branch exists only at the remote", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.CreateGitTown(t)
+			repoDir := t.TempDir()
+			repo := testruntime.Clone(origin.TestRunner, repoDir)
+			branch := gitdomain.NewLocalBranchName("branch")
+			main := gitdomain.NewRemoteBranchName("origin/main")
+			repo.CreateFeatureBranch(branch, main.BranchName())
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file_1",
+				Message:  "commit message 1",
+			})
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file_2",
+				Message:  "commit message 2",
+			})
+			repo.CreateCommit(testgit.Commit{
+				Branch:   branch,
+				FileName: "file_3",
+				Message:  "commit message 3",
+			})
+			repo.PushBranchToRemote(branch, gitdomain.RemoteOrigin)
+			repo.CheckoutBranch(main.LocalBranchName())
+			err := repo.DeleteLocalBranch(repo.TestRunner, branch)
+			must.NoError(t, err)
+			have, err := repo.FirstCommitMessageInBranch(repo.TestRunner, branch.TrackingBranch().BranchName(), main.BranchName())
+			must.NoError(t, err)
+			want := Some(gitdomain.CommitMessage("commit message 1"))
+			must.Eq(t, want, have)
+		})
+	})
+
 	t.Run("FirstExistingBranch", func(t *testing.T) {
 		t.Parallel()
 		t.Run("first branch matches", func(t *testing.T) {
@@ -188,8 +280,8 @@ func TestBackendCommands(t *testing.T) {
 			runtime := testruntime.Create(t)
 			branch1 := gitdomain.NewLocalBranchName("b1")
 			branch2 := gitdomain.NewLocalBranchName("b2")
-			runtime.CreateBranch(branch1, initial)
-			runtime.CreateBranch(branch2, initial)
+			runtime.CreateBranch(branch1, initial.BranchName())
+			runtime.CreateBranch(branch2, initial.BranchName())
 			have := runtime.Commands.FirstExistingBranch(runtime.TestCommands, branch1, branch2)
 			want := Some(branch1)
 			must.Eq(t, want, have)
@@ -199,7 +291,7 @@ func TestBackendCommands(t *testing.T) {
 			runtime := testruntime.Create(t)
 			branch1 := gitdomain.NewLocalBranchName("b1")
 			branch2 := gitdomain.NewLocalBranchName("b2")
-			runtime.CreateBranch(branch2, initial)
+			runtime.CreateBranch(branch2, initial.BranchName())
 			have := runtime.Commands.FirstExistingBranch(runtime.TestCommands, branch1, branch2)
 			want := Some(branch2)
 			must.Eq(t, want, have)
@@ -220,8 +312,8 @@ func TestBackendCommands(t *testing.T) {
 		origin := testruntime.Create(t)
 		repoDir := t.TempDir()
 		runner := testruntime.Clone(origin.TestRunner, repoDir)
-		runner.CreateBranch(gitdomain.NewLocalBranchName("b1"), initial)
-		runner.CreateBranch(gitdomain.NewLocalBranchName("b2"), initial)
+		runner.CreateBranch(gitdomain.NewLocalBranchName("b1"), initial.BranchName())
+		runner.CreateBranch(gitdomain.NewLocalBranchName("b2"), initial.BranchName())
 		must.True(t, runner.Commands.HasLocalBranch(runner.TestCommands, gitdomain.NewLocalBranchName("b1")))
 		must.True(t, runner.Commands.HasLocalBranch(runner.TestCommands, gitdomain.NewLocalBranchName("b2")))
 		must.False(t, runner.Commands.HasLocalBranch(runner.TestCommands, gitdomain.NewLocalBranchName("b3")))
@@ -286,7 +378,7 @@ func TestBackendCommands(t *testing.T) {
 				t.Parallel()
 				runtime := testruntime.Create(t)
 				branch1 := gitdomain.NewLocalBranchName("branch1")
-				runtime.CreateBranch(branch1, initial)
+				runtime.CreateBranch(branch1, initial.BranchName())
 				runtime.CheckoutBranch(branch1)
 				runtime.CreateCommit(testgit.Commit{
 					Branch:      branch1,
@@ -310,7 +402,7 @@ func TestBackendCommands(t *testing.T) {
 				t.Parallel()
 				runtime := testruntime.Create(t)
 				branch1 := gitdomain.NewLocalBranchName("branch1")
-				runtime.CreateBranch(branch1, initial)
+				runtime.CreateBranch(branch1, initial.BranchName())
 				runtime.CheckoutBranch(branch1)
 				runtime.CreateCommit(testgit.Commit{
 					Branch:      branch1,
@@ -773,8 +865,8 @@ func TestBackendCommands(t *testing.T) {
 	t.Run("PreviouslyCheckedOutBranch", func(t *testing.T) {
 		t.Parallel()
 		runtime := testruntime.Create(t)
-		runtime.CreateBranch(gitdomain.NewLocalBranchName("feature1"), initial)
-		runtime.CreateBranch(gitdomain.NewLocalBranchName("feature2"), initial)
+		runtime.CreateBranch(gitdomain.NewLocalBranchName("feature1"), initial.BranchName())
+		runtime.CreateBranch(gitdomain.NewLocalBranchName("feature2"), initial.BranchName())
 		runtime.CheckoutBranch(gitdomain.NewLocalBranchName("feature1"))
 		runtime.CheckoutBranch(gitdomain.NewLocalBranchName("feature2"))
 		have := runtime.Commands.PreviouslyCheckedOutBranch(runtime.TestRunner)
@@ -816,6 +908,84 @@ func TestBackendCommands(t *testing.T) {
 		})
 	})
 
+	t.Run("ShouldPushBranch", func(t *testing.T) {
+		t.Parallel()
+		t.Run("branch has no commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			must.False(t, shouldPush)
+		})
+		t.Run("branch has local commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "local_file",
+				Message:     "add local file",
+			})
+			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			must.True(t, shouldPush)
+		})
+		t.Run("branch has remote commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			origin.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "remote_file",
+				Message:     "add remote file",
+			})
+			local.Fetch()
+			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			must.True(t, shouldPush)
+		})
+		t.Run("branch has different local and remote commits", func(t *testing.T) {
+			t.Parallel()
+			origin := testruntime.Create(t)
+			local := testruntime.Clone(origin.TestRunner, t.TempDir())
+			err := local.CreateAndCheckoutBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			err = local.CreateTrackingBranch(local.TestRunner, "branch", gitdomain.RemoteOrigin, false)
+			must.NoError(t, err)
+			local.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "local_file",
+				Message:     "add local file",
+			})
+			origin.CreateCommit(testgit.Commit{
+				Branch:      "branch",
+				FileContent: "content",
+				FileName:    "remote_file",
+				Message:     "add remote file",
+			})
+			local.Fetch()
+			shouldPush, err := local.ShouldPushBranch(local.TestRunner, "branch")
+			must.NoError(t, err)
+			must.True(t, shouldPush)
+		})
+	})
+
 	t.Run("StashEntries", func(t *testing.T) {
 		t.Parallel()
 		t.Run("some stash entries", func(t *testing.T) {
