@@ -3,14 +3,14 @@ package hosting
 import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/giturl"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/hosting/bitbucket"
 	"github.com/git-town/git-town/v15/internal/hosting/gitea"
 	"github.com/git-town/git-town/v15/internal/hosting/github"
 	"github.com/git-town/git-town/v15/internal/hosting/gitlab"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
-func Detect(originURL giturl.Parts, userOverride Option[configdomain.HostingPlatform]) Option[configdomain.HostingPlatform] {
+func Detect(remoteURL giturl.Parts, userOverride Option[configdomain.HostingPlatform]) Option[configdomain.HostingPlatform] {
 	if userOverride.IsSome() {
 		return userOverride
 	}
@@ -21,7 +21,7 @@ func Detect(originURL giturl.Parts, userOverride Option[configdomain.HostingPlat
 		configdomain.HostingPlatformGitLab:    gitlab.Detect,
 	}
 	for platform, detector := range detectors {
-		if detector(originURL) {
+		if detector(remoteURL) {
 			return Some(platform)
 		}
 	}
