@@ -11,9 +11,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/git/giturl"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/messages"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"golang.org/x/oauth2"
 )
 
@@ -39,19 +39,20 @@ func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Op
 		return None[hostingdomain.Proposal](), err
 	}
 	pullRequests := FilterPullRequests(openPullRequests, self.Organization, branch, target)
-	if len(pullRequests) == 0 {
+	switch len(pullRequests) {
+	case 0:
 		return None[hostingdomain.Proposal](), nil
-	}
-	if len(pullRequests) > 1 {
+	case 1:
+		pullRequest := pullRequests[0]
+		return Some(hostingdomain.Proposal{
+			MergeWithAPI: pullRequest.Mergeable,
+			Number:       int(pullRequest.Index),
+			Target:       gitdomain.NewLocalBranchName(pullRequest.Base.Ref),
+			Title:        pullRequest.Title,
+		}), nil
+	default:
 		return None[hostingdomain.Proposal](), fmt.Errorf(messages.ProposalMultipleFound, len(pullRequests), branch, target)
 	}
-	pullRequest := pullRequests[0]
-	return Some(hostingdomain.Proposal{
-		MergeWithAPI: pullRequest.Mergeable,
-		Number:       int(pullRequest.Index),
-		Target:       gitdomain.NewLocalBranchName(pullRequest.Base.Ref),
-		Title:        pullRequest.Title,
-	}), nil
 }
 
 func (self Connector) NewProposalURL(branch, parentBranch, _ gitdomain.LocalBranchName, _ gitdomain.ProposalTitle, _ gitdomain.ProposalBody) (string, error) {
@@ -108,13 +109,13 @@ func FilterPullRequests(pullRequests []*gitea.PullRequest, organization string,
 func NewConnector(args NewConnectorArgs) Connector {
 	tokenSource := oauth2.StaticTokenSource(&oauth2.Token{AccessToken: args.APIToken.String()})
 	httpClient := oauth2.NewClient(context.Background(), tokenSource)
-	giteaClient := gitea.NewClientWithHTTP("https://"+args.OriginURL.Host, httpClient)
+	giteaClient := gitea.NewClientWithHTTP("https://"+args.RemoteURL.Host, httpClient)
 	return Connector{
 		APIToken: args.APIToken,
 		Data: hostingdomain.Data{
-			Hostname:     args.OriginURL.Host,
-			Organization: args.OriginURL.Org,
-			Repository:   args.OriginURL.Repo,
+			Hostname:     args.RemoteURL.Host,
+			Organization: args.RemoteURL.Org,
+			Repository:   args.RemoteURL.Repo,
 		},
 		client: giteaClient,
 		log:    args.Log,
@@ -124,5 +125,5 @@ func NewConnector(args NewConnectorArgs) Connector {
 type NewConnectorArgs struct {
 	APIToken  Option[configdomain.GiteaToken]
 	Log       print.Logger
-	OriginURL giturl.Parts
+	RemoteURL giturl.Parts
 }
