@@ -9,9 +9,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/git/giturl"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
 	"github.com/git-town/git-town/v15/internal/messages"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/xanzy/go-gitlab"
 )
 
@@ -33,14 +33,14 @@ func (self Connector) FindProposal(branch, target gitdomain.LocalBranchName) (Op
 	if err != nil {
 		return None[hostingdomain.Proposal](), err
 	}
-	if len(mergeRequests) == 0 {
+	switch len(mergeRequests) {
+	case 0:
 		return None[hostingdomain.Proposal](), nil
-	}
-	if len(mergeRequests) > 1 {
+	case 1:
+		return Some(parseMergeRequest(mergeRequests[0])), nil
+	default:
 		return None[hostingdomain.Proposal](), fmt.Errorf(messages.ProposalMultipleFound, len(mergeRequests), branch, target)
 	}
-	proposal := parseMergeRequest(mergeRequests[0])
-	return Some(proposal), nil
 }
 
 func (self Connector) SquashMergeProposal(number int, message gitdomain.CommitMessage) error {
@@ -82,9 +82,9 @@ func NewConnector(args NewConnectorArgs) (Connector, error) {
 	gitlabData := Data{
 		APIToken: args.APIToken,
 		Data: hostingdomain.Data{
-			Hostname:     args.OriginURL.Host,
-			Organization: args.OriginURL.Org,
-			Repository:   args.OriginURL.Repo,
+			Hostname:     args.RemoteURL.Host,
+			Organization: args.RemoteURL.Org,
+			Repository:   args.RemoteURL.Repo,
 		},
 	}
 	clientOptFunc := gitlab.WithBaseURL(gitlabData.baseURL())
@@ -104,7 +104,7 @@ func NewConnector(args NewConnectorArgs) (Connector, error) {
 type NewConnectorArgs struct {
 	APIToken  Option[configdomain.GitLabToken]
 	Log       print.Logger
-	OriginURL giturl.Parts
+	RemoteURL giturl.Parts
 }
 
 func parseMergeRequest(mergeRequest *gitlab.MergeRequest) hostingdomain.Proposal {
