@@ -2,7 +2,7 @@ package hostingdomain
 
 import (
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // Connector describes the activities that Git Town can perform on code hosting platforms.
