@@ -15,6 +15,7 @@ const (
 	BranchDoesntContainCommit         = "branch %q does not contain commit %q. Found commits %s"
 	BranchDoesntExist                 = "there is no branch %q"
 	BranchHasWrongSHA                 = "cannot reset branch %q to %q because it received additional commits in the meantime. It should have SHA %q but has %q"
+	BranchInfoNotFound                = "cannot find branch info for %q"
 	BranchIsAlreadyContribution       = "branch %q is already a contribution branch"
 	BranchIsAlreadyObserved           = "branch %q is already observed"
 	BranchIsAlreadyPrototype          = "branch %q is already a prototype branch"
@@ -50,6 +51,7 @@ const (
 	ContinueMessage                   = `You can run "git town continue" to finish it.`
 	ContinueSkipGuidance              = "To continue by skipping the current branch, run \"git town skip\"."
 	ContributeBranchIsNowContribution = "branch %q is now a contribution branch\n"
+	ContributeBranchIsLocal           = "branch %q is local only - branches you want to contribute to must have a remote branch because they are per definition other people's branches"
 	ContributionBranchCannotPark      = "cannot park contribution branches"
 	ContributionBranchCannotPropose   = "cannot propose contribution branches"
 	ContributionBranchCannotShip      = "cannot ship contribution branches"
@@ -124,6 +126,7 @@ END OUTPUT FROM 'git branch -vva'
 	ObservedBranchCannotPark              = "cannot park observed branches"
 	ObservedBranchCannotPropose           = "cannot propose observed branches"
 	ObservedBranchCannotShip              = "cannot ship observed branches"
+	ObserveBranchIsLocal                  = "branch %q is local only - branches you want to observe must have a remote branch because they are per definition other people's branches"
 	ObservedBranchIsNowObserved           = "branch %q is now an observed branch\n"
 	OfflineNotAllowed                     = "this command requires an active internet connection"
 	OpcodeUnknown                         = "unknown opcode: %q, run \"git town status reset\" to reset it"
@@ -208,6 +211,7 @@ nd will be removed in future versions of Git Town.`
 	SyncFeatureBranches            = "Sync feature branches: %s\n"
 	SyncPerennialBranches          = "Sync perennial branches: %s\n"
 	SyncStatusNotRecognized        = "cannot determine the sync status for Git remote %q and branch name %q"
+	SyncTags                       = "Sync tags: %s\n"
 	SyncWithUpstream               = "Sync with upstream: %s\n"
 	UndoCreateOpcodeProblem        = "cannot create undo operations for %q: %w"
 	UndoMessage                    = `You can run "git town undo" to go back to where you started.`
