@@ -10,8 +10,8 @@ import (
 	"github.com/git-town/git-town/v15/internal/cli/colors"
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // BackendRunner executes backend shell commands without output to the CLI.
