@@ -2,9 +2,9 @@ package sync
 
 import (
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/vm/opcodes"
 	"github.com/git-town/git-town/v15/internal/vm/program"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // PerennialBranchProgram adds the opcodes to sync the observed branch with the given name.
