@@ -9,12 +9,12 @@ import (
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/messages"
 	lightInterpreter "github.com/git-town/git-town/v15/internal/vm/interpreter/light"
 	"github.com/git-town/git-town/v15/internal/vm/runstate"
 	"github.com/git-town/git-town/v15/internal/vm/statefile"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // undoes the persisted runstate
