@@ -1,14 +1,15 @@
 package opcodes
 
 import (
-	"fmt"
-
+	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/vm/shared"
 )
 
 // CommitOpenChanges commits all open changes as a new commit.
 // It does not ask the user for a commit message, but chooses one automatically.
 type CommitOpenChanges struct {
+	AddAll                  bool
+	Message                 gitdomain.CommitMessage
 	undeclaredOpcodeMethods `exhaustruct:"optional"`
 }
 
@@ -17,13 +18,11 @@ func (self *CommitOpenChanges) CreateContinueProgram() []shared.Opcode {
 }
 
 func (self *CommitOpenChanges) Run(args shared.RunArgs) error {
-	err := args.Git.StageFiles(args.Frontend, "-A")
-	if err != nil {
-		return err
+	if self.AddAll {
+		err := args.Git.StageFiles(args.Frontend, "-A")
+		if err != nil {
+			return err
+		}
 	}
-	currentBranch, err := args.Git.CurrentBranch(args.Backend)
-	if err != nil {
-		return err
-	}
-	return args.Git.CommitStagedChanges(args.Frontend, fmt.Sprintf("WIP on %s", currentBranch))
+	return args.Git.CommitStagedChanges(args.Frontend, self.Message)
 }
