@@ -16,7 +16,7 @@ func (self *PushCurrentBranch) CreateContinueProgram() []shared.Opcode {
 }
 
 func (self *PushCurrentBranch) Run(args shared.RunArgs) error {
-	shouldPush, err := args.Git.ShouldPushBranch(args.Backend, self.CurrentBranch, self.CurrentBranch.TrackingBranch())
+	shouldPush, err := args.Git.ShouldPushBranch(args.Backend, self.CurrentBranch)
 	if err != nil {
 		return err
 	}
