@@ -5,9 +5,9 @@ import (
 	"github.com/git-town/git-town/v15/internal/config"
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
 	"github.com/git-town/git-town/v15/internal/hosting/hostingdomain"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 type RunArgs struct {
