@@ -6,9 +6,9 @@ import (
 	"os"
 
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/messages"
 	"github.com/git-town/git-town/v15/internal/vm/runstate"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 )
 
 // Load loads the run state for the given Git repo from disk.
