@@ -19,7 +19,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/config/configdomain"
 	"github.com/git-town/git-town/v15/internal/config/configfile"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/git-town/git-town/v15/test/asserts"
 	"github.com/git-town/git-town/v15/test/commands"
 	"github.com/git-town/git-town/v15/test/datatable"
@@ -105,6 +105,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 		fixture := fixtureFactory.CreateFixture(scenarioName)
 		if helpers.HasTag(scenarioTags, "@debug") {
 			fixture.DevRepo.GetOrPanic().Verbose = true
+			fixture.OriginRepo.GetOrPanic().Verbose = true
 		}
 		state := ScenarioState{
 			fixture:              fixture,
@@ -114,6 +115,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 			initialDevSHAs:       None[map[string]gitdomain.SHA](),
 			initialLineage:       None[datatable.DataTable](),
 			initialOriginSHAs:    None[map[string]gitdomain.SHA](),
+			initialTags:          None[datatable.DataTable](),
 			initialWorktreeSHAs:  None[map[string]gitdomain.SHA](),
 			insideGitRepo:        true,
 			runExitCode:          None[int](),
@@ -152,6 +154,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 			initialDevSHAs:       None[map[string]gitdomain.SHA](),
 			initialLineage:       None[datatable.DataTable](),
 			initialOriginSHAs:    None[map[string]gitdomain.SHA](),
+			initialTags:          None[datatable.DataTable](),
 			initialWorktreeSHAs:  None[map[string]gitdomain.SHA](),
 			insideGitRepo:        true,
 			runExitCode:          None[int](),
@@ -171,6 +174,12 @@ func defineSteps(sc *godog.ScenarioContext) {
 		}
 	})
 
+	sc.Step(`^an additional "([^"]+)" remote with URL "([^"]+)"$`, func(ctx context.Context, remote, url string) {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		devRepo.AddRemote(gitdomain.NewRemote(remote), url)
+	})
+
 	sc.Step(`^an uncommitted file$`, func(ctx context.Context) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -493,7 +502,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo.CreateCommit(git.Commit{
 			Branch:   gitdomain.NewLocalBranchName(branch),
 			FileName: "new_file",
-			Message:  message,
+			Message:  gitdomain.CommitMessage(message),
 		})
 	})
 
@@ -538,6 +547,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 			initialDevSHAs:       None[map[string]gitdomain.SHA](),
 			initialLineage:       None[datatable.DataTable](),
 			initialOriginSHAs:    None[map[string]gitdomain.SHA](),
+			initialTags:          None[datatable.DataTable](),
 			initialWorktreeSHAs:  None[map[string]gitdomain.SHA](),
 			insideGitRepo:        true,
 			runExitCode:          None[int](),
@@ -606,6 +616,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 		if content == "" {
 			content = "resolved content"
 		}
+		content = strings.ReplaceAll(content, "\\n", "\n")
 		devRepo.CreateFile(filename, content)
 		devRepo.StageFiles(filename)
 	})
@@ -941,13 +952,22 @@ func defineSteps(sc *godog.ScenarioContext) {
 		state.fixture.OriginRepo.GetOrPanic().RemoveBranch(gitdomain.NewLocalBranchName(branch))
 	})
 
-	sc.Step(`^origin ships the "([^"]*)" branch$`, func(ctx context.Context, branch string) {
+	sc.Step(`^origin ships the "([^"]*)" branch$`, func(ctx context.Context, branchName string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		branchToShip := gitdomain.NewLocalBranchName(branchName)
 		originRepo := state.fixture.OriginRepo.GetOrPanic()
-		originRepo.CheckoutBranch(gitdomain.NewLocalBranchName("main"))
-		err := originRepo.MergeBranch(gitdomain.NewLocalBranchName(branch))
+		commitMessage, err := originRepo.FirstCommitMessageInBranch(originRepo.TestRunner, branchToShip.BranchName(), "main")
 		asserts.NoError(err)
-		originRepo.RemoveBranch(gitdomain.NewLocalBranchName(branch))
+		if commitMessage.IsNone() {
+			panic("branch to ship contains no commits")
+		}
+		originRepo.CheckoutBranch("main")
+		err = originRepo.SquashMerge(originRepo.TestRunner, branchToShip)
+		asserts.NoError(err)
+		originRepo.StageFiles("-A")
+		err = originRepo.Commit(originRepo.TestRunner, commitMessage, "CI <ci@acme.com>")
+		asserts.NoError(err)
+		originRepo.RemoveBranch(branchToShip)
 	})
 
 	sc.Step(`^the branch(es)?$`, func(ctx context.Context, plural string, table *godog.Table) {
@@ -1066,6 +1086,19 @@ func defineSteps(sc *godog.ScenarioContext) {
 		}
 	})
 
+	sc.Step(`^the contribution branches are (?:now|still) "([^"]+)"$`, func(ctx context.Context, name string) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		actual := devRepo.Config.LocalGitConfig.ContributionBranches
+		if len(actual) != 1 {
+			return fmt.Errorf("expected 1 contribution branch, got %q", actual)
+		}
+		if (actual)[0].String() != name {
+			return fmt.Errorf("expected %q, got %q", name, (actual)[0])
+		}
+		return nil
+	})
+
 	sc.Step(`^the coworker adds this commit to their current branch:$`, func(ctx context.Context, table *godog.Table) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		commits := git.FromGherkinTable(table)
@@ -1279,6 +1312,17 @@ func defineSteps(sc *godog.ScenarioContext) {
 		}
 	})
 
+	sc.Step(`^the initial tags exist now$`, func(ctx context.Context) {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		currentTags := state.fixture.TagTable()
+		errDiff, errCount := state.initialTags.GetOrPanic().EqualDataTable(currentTags)
+		if errCount == 0 {
+			return
+		}
+		fmt.Println(errDiff)
+		panic("current tags are not the same as the initial commits")
+	})
+
 	sc.Step(`^the main branch is "([^"]+)"$`, func(ctx context.Context, name string) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -1305,12 +1349,38 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
+	sc.Step(`^the observed branches are (?:now|still) "([^"]+)"$`, func(ctx context.Context, name string) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		actual := devRepo.Config.LocalGitConfig.ObservedBranches
+		if len(actual) != 1 {
+			return fmt.Errorf("expected 1 observed branch, got %q", actual)
+		}
+		if (actual)[0].String() != name {
+			return fmt.Errorf("expected %q, got %q", name, (actual)[0])
+		}
+		return nil
+	})
+
 	sc.Step(`^the origin is "([^"]*)"$`, func(ctx context.Context, origin string) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
 		devRepo.SetTestOrigin(origin)
 	})
 
+	sc.Step(`^the parked branches are (?:now|still) "([^"]+)"$`, func(ctx context.Context, name string) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		actual := devRepo.Config.LocalGitConfig.ParkedBranches
+		if len(actual) != 1 {
+			return fmt.Errorf("expected 1 parked branch, got %q", actual)
+		}
+		if (actual)[0].String() != name {
+			return fmt.Errorf("expected %q, got %q", name, (actual)[0])
+		}
+		return nil
+	})
+
 	sc.Step(`^the perennial branches are "([^"]+)"$`, func(ctx context.Context, name string) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -1353,6 +1423,19 @@ func defineSteps(sc *godog.ScenarioContext) {
 		return nil
 	})
 
+	sc.Step(`^the prototype branches are (?:now|still) "([^"]+)"$`, func(ctx context.Context, name string) error {
+		state := ctx.Value(keyScenarioState).(*ScenarioState)
+		devRepo := state.fixture.DevRepo.GetOrPanic()
+		actual := devRepo.Config.LocalGitConfig.PrototypeBranches
+		if len(actual) != 1 {
+			return fmt.Errorf("expected 1 prototype branch, got %q", actual)
+		}
+		if (actual)[0].String() != name {
+			return fmt.Errorf("expected %q, got %q", name, (actual)[0])
+		}
+		return nil
+	})
+
 	sc.Step(`^there are (?:now|still) no contribution branches$`, func(ctx context.Context) error {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		devRepo := state.fixture.DevRepo.GetOrPanic()
@@ -1432,7 +1515,7 @@ func defineSteps(sc *godog.ScenarioContext) {
 		}
 	})
 
-	sc.Step(`^these tags exist$`, func(ctx context.Context, table *godog.Table) {
+	sc.Step(`^these tags exist now$`, func(ctx context.Context, table *godog.Table) {
 		state := ctx.Value(keyScenarioState).(*ScenarioState)
 		tagTable := state.fixture.TagTable()
 		diff, errorCount := tagTable.EqualGherkin(table)
@@ -1500,6 +1583,12 @@ func defineSteps(sc *godog.ScenarioContext) {
 		devRepo := state.fixture.DevRepo.GetOrPanic()
 		devRepo.MockCommand(tool)
 	})
+
+	// This step exists to avoid re-creating commits with the same SHA as existing commits
+	// because that can cause flaky tests.
+	sc.Step(`wait 1 second to ensure new Git timestamps`, func() {
+		time.Sleep(1 * time.Second)
+	})
 }
 
 func updateInitialSHAs(state *ScenarioState) {
