@@ -11,8 +11,8 @@ import (
 	"github.com/cucumber/godog"
 
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
 	"github.com/git-town/git-town/v15/internal/gohacks/stringslice"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/sergi/go-diff/diffmatchpatch"
 	"golang.org/x/exp/maps"
 )
@@ -82,6 +82,9 @@ func (self *DataTable) Expand(localRepo runner, remoteRepo runner, worktreeRepo
 				case strings.HasPrefix(match, "{{ sha "):
 					commitName := match[8 : len(match)-4]
 					shas := localRepo.SHAsForCommit(commitName)
+					if len(shas) == 0 {
+						panic(fmt.Sprintf("test workspace has no commit %q", commitName))
+					}
 					sha := shas.First()
 					cell = strings.Replace(cell, match, sha.String(), 1)
 				case strings.HasPrefix(match, "{{ sha-in-origin "):
