@@ -4,7 +4,7 @@ import (
 	"os"
 	"testing"
 
-	"github.com/git-town/git-town/v14/test/fixture"
+	"github.com/git-town/git-town/v15/test/fixture"
 	"github.com/shoenig/test/must"
 )
 
@@ -16,7 +16,7 @@ func TestFixtureFactory(t *testing.T) {
 		factory := fixture.CreateFactory()
 		defer factory.Remove()
 		result := factory.CreateFixture("foo")
-		_, err := os.Stat(result.DevRepo.WorkingDir)
+		_, err := os.Stat(result.DevRepo.GetOrPanic().WorkingDir)
 		must.False(t, os.IsNotExist(err))
 	})
 }
