@@ -10,7 +10,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks/cache"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/git-town/git-town/v15/test/asserts"
 	"github.com/git-town/git-town/v15/test/commands"
 	"github.com/git-town/git-town/v15/test/datatable"
@@ -96,6 +96,7 @@ func (self *Fixture) AddSubmoduleRepo() {
 func (self *Fixture) AddUpstream() {
 	devRepo := self.DevRepo.GetOrPanic()
 	upstreamRepo := testruntime.Clone(devRepo.TestRunner, filepath.Join(self.Dir, gitdomain.RemoteUpstream.String()))
+	upstreamRepo.TestRunner.Verbose = devRepo.Verbose
 	self.UpstreamRepo = SomeP(&upstreamRepo)
 	devRepo.AddRemote(gitdomain.RemoteUpstream, upstreamRepo.WorkingDir)
 }
