@@ -1,9 +1,9 @@
 package helpers
 
-import "github.com/cucumber/messages-go/v10"
+import "github.com/cucumber/godog"
 
 // TableFields provides the header fields of the given table.
-func TableFields(table *messages.PickleStepArgument_PickleTable) []string {
+func TableFields(table *godog.Table) []string {
 	result := []string{}
 	for _, cell := range table.Rows[0].Cells {
 		result = append(result, cell.Value)
