@@ -11,7 +11,7 @@ import (
 	"github.com/git-town/git-town/v15/internal/git"
 	"github.com/git-town/git-town/v15/internal/git/gitdomain"
 	"github.com/git-town/git-town/v15/internal/gohacks/cache"
-	. "github.com/git-town/git-town/v15/internal/gohacks/prelude"
+	. "github.com/git-town/git-town/v15/pkg/prelude"
 	"github.com/git-town/git-town/v15/test/commands"
 	testshell "github.com/git-town/git-town/v15/test/subshell"
 	"github.com/shoenig/test/must"
@@ -50,7 +50,7 @@ func Create(t *testing.T) TestRuntime {
 func CreateGitTown(t *testing.T) TestRuntime {
 	t.Helper()
 	repo := Create(t)
-	repo.CreateBranch(gitdomain.NewLocalBranchName("main"), gitdomain.NewLocalBranchName("initial"))
+	repo.CreateBranch(gitdomain.NewLocalBranchName("main"), gitdomain.NewBranchName("initial"))
 	err := repo.Config.SetMainBranch(gitdomain.NewLocalBranchName("main"))
 	must.NoError(t, err)
 	err = repo.Config.SetPerennialBranches(gitdomain.LocalBranchNames{})
