@@ -8,7 +8,7 @@ import (
 	"github.com/google/go-github/v58/github"
 )
 
-func (gh Connector) CommentReactions(comment *github.IssueComment) []*github.Reaction {
+func (gh Connector) CommentReactions(comment github.IssueComment) []*github.Reaction {
 	result := []*github.Reaction{}
 	if *comment.Reactions.TotalCount == 0 {
 		return result
@@ -32,7 +32,7 @@ func (gh Connector) CommentReactions(comment *github.IssueComment) []*github.Rea
 	} else {
 		texts := make([]string, len(result))
 		for r, reaction := range result {
-			texts[r] = fmt.Sprintf("%s (%s)", *reaction.Content, reactionAuthor(reaction))
+			texts[r] = fmt.Sprintf("%s (%s)", *reaction.Content, reactionAuthor(*reaction))
 		}
 		fmt.Printf(" %s\n  %s\n", console.Green.Styled("ok"), strings.Join(texts, ", "))
 	}
